---
title: "Examples - Get Started"
format:
html:
code-fold: true
jupyter: python3
---

This example shows a basic example of the Aligner

```{python}
#| fig-cap: "basic example"
{{< include ../examples/example_readme.py >}}
```

This example shows a plotted example

```{python}
#| fig-cap: "plotted example"
{{< include ../examples/example_readme.py >}}
```